@@ -4,18 +4,18 @@
 #' @name argo
 #' @template argo_params
 #' @template argo_egs
-argo_search <- function(func = NULL, of = NULL, qwmo = NULL, wmo = NULL, box=NULL,
-                        area = NULL, around = NULL, year = NULL, yearmin = NULL,
-                        yearmax = NULL, month = NULL, monthmin = NULL, monthmax = NULL,
-                        lr = NULL, from =NULL, to = NULL, dmode = NULL,
-                        pres_qc = NULL, temp_qc = NULL, psal_qc = NULL, doxy_qc = NULL,
-                        ticket = NULL, limit = 10, ...) {
+argo_search <- function(func = NULL, of = NULL, qwmo = NULL, wmo = NULL,
+  box=NULL, area = NULL, around = NULL, year = NULL, yearmin = NULL,
+  yearmax = NULL, month = NULL, monthmin = NULL, monthmax = NULL, lr = NULL,
+  from =NULL, to = NULL, dmode = NULL, pres_qc = NULL, temp_qc = NULL,
+  psal_qc = NULL, doxy_qc = NULL, ticket = NULL, limit = 10, ...) {
 
   if (!is.null(box)) box <- paste0(box, collapse = ",")
   args <- noaa_compact(list(get = func, of = of, qwmo = qwmo, wmo = wmo,
       box = box, area = area, around = around, year = year, yearmin = yearmin,
-      yearmax = yearmax, month = month, monthmin = monthmin, monthmax = monthmax,
-      lr = lr, from = from, to = to, dmode = dmode, pres_qc = pres_qc, temp_qc = temp_qc,
+      yearmax = yearmax, month = month, monthmin = monthmin,
+      monthmax = monthmax, lr = lr, from = from, to = to, dmode = dmode,
+      pres_qc = pres_qc, temp_qc = temp_qc,
       psal_qc = psal_qc, doxy_qc = doxy_qc, ticket = ticket, limit = limit))
   res <- argo_GET(url = argo_api(), args, ...)
   jsonlite::fromJSON(utcf8(res))
@@ -71,7 +71,8 @@ argo <- function(dac, id, cycle, dtype, overwrite = TRUE, ...) {
   apath <- a_local(dac, id, cycle, dtype, path)
   if (!is_isd(apath)) {
     dir.create(path, showWarnings = FALSE, recursive = TRUE)
-    suppressWarnings(argo_GET(a_remote(dac, id, cycle, dtype), list(), write_disk(apath, overwrite), ...))
+    suppressWarnings(argo_GET(a_remote(dac, id, cycle, dtype), list(),
+                              write_disk(apath, overwrite), ...))
   }
   message(sprintf("<path> %s", apath), "\n")
   ncdf4::nc_open(apath)
@@ -85,7 +86,7 @@ argo_GET <- function(url, args = list(), ...) {
 }
 
 argo_base <- function() "http://www.ifremer.fr/"
-argo_api <- function() paste0(argo_base(), "lpo/naarc/api/v1")
+argo_api <- function() paste0(argo_base(), "lpo/naarc/api/v1/")
 argo_ftp <- function() "ftp://ftp.ifremer.fr/ifremer/argo/"
 
 a_local <- function(dac, id, cycle, dtype, path) {
@@ -93,5 +94,6 @@ a_local <- function(dac, id, cycle, dtype, path) {
 }
 
 a_remote <- function(dac, id, cycle, dtype) {
-  file.path(argo_ftp(), "dac", dac, id, "profiles", sprintf("%s%s_%s.nc", dtype, id, cycle))
+  file.path(argo_ftp(), "dac", dac, id, "profiles",
+            sprintf("%s%s_%s.nc", dtype, id, cycle))
 }
