@@ -134,6 +134,39 @@ erddap_table <- function(){
   .Defunct(new = "tabledap", msg = "See tabledap() in package rerddap")
 }
 
+
+#' This function is defunct.
+#' @export
+#' @rdname ncdc_leg_variables-defunct
+#' @keywords internal
+ncdc_leg_variables <- function(){
+  .Defunct(msg = "This function is defunct, see ncdc_*() functions")
+}
+
+#' This function is defunct.
+#' @export
+#' @rdname ncdc_leg_sites-defunct
+#' @keywords internal
+ncdc_leg_sites <- function() {
+  .Defunct(msg = "This function is defunct, see ncdc_*() functions")
+}
+
+#' This function is defunct.
+#' @export
+#' @rdname ncdc_leg_site_info-defunct
+#' @keywords internal
+ncdc_leg_site_info <- function() {
+  .Defunct(msg = "This function is defunct, see ncdc_*() functions")
+}
+
+#' This function is defunct.
+#' @export
+#' @rdname ncdc_leg_data-defunct
+#' @keywords internal
+ncdc_leg_data <- function() {
+  .Defunct(msg = "This function is defunct, see ncdc_*() functions")
+}
+
 #' Defunct functions in rnoaa
 #'
 #' \itemize{
@@ -159,7 +192,17 @@ erddap_table <- function(){
 #'  package rerddap
 #'  \item \code{\link{erddap_table}}: Moved to \code{tabledap} in
 #'  package rerddap
+#'  \item \code{\link{ncdc_leg_variables}}: Removed. See \code{NCDC Legacy} below
+#'  \item \code{\link{ncdc_leg_sites}}: Removed. See \code{NCDC Legacy} below
+#'  \item \code{\link{ncdc_leg_site_info}}: Removed. See \code{NCDC Legacy} below
+#'  \item \code{\link{ncdc_leg_data}}: Removed. See \code{NCDC Legacy} below
 #' }
+#' 
+#' @section NCDC Legacy:
+#' The NCDC legacy API is too unreliable and slow. Use the newer NCDC API via the 
+#' functions \code{\link{ncdc}}, \code{\link{ncdc_datacats}}, \code{\link{ncdc_datasets}},
+#' \code{\link{ncdc_datatypes}}, \code{\link{ncdc_locs}}, \code{\link{ncdc_locs_cats}},
+#' \code{\link{ncdc_stations}}, \code{\link{ncdc_plot}}, and \code{\link{ncdc_combine}}
 #'
 #' @name rnoaa-defunct
 NULL
